#========================================================================================
# package      DE_EPAGES::Paynet::Hooks::Attribute
# state        private
#========================================================================================
package DE_EPAGES::Paynet::Hooks::Attribute;

use strict;
use DE_EPAGES::Object::API::Factory qw (LoadObjectByPath GetRootObjectID);
use DE_EPAGES::ThirdPartyConfig::API::Constants qw (ATTRIBUTES_CATEGORY_PAYMENT);

#========================================================================================
# function     OnGetThirdPartyConfigAttributes
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnGetThirdPartyConfigAttributes($hParams);
#----------------------------------------------------------------------------------------
# description  API_GetThirdPartyConfigAttributes triggered, register attributes to be
#               configured in PBO
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>AttributesCategory
#                   <li>LanguageID
#               </ul> | ref.hash.*
#========================================================================================
sub OnGetThirdPartyConfigAttributes {
    my ($hParams) = @_;

    return unless $hParams->{'AttributesCategory'} eq ATTRIBUTES_CATEGORY_PAYMENT;

    my $PaymentType  = LoadObjectByPath('/PaymentTypes/Paynet');
    my $RootObjectID = GetRootObjectID();

    push(@{$hParams->{'Attributes'}}, {
        'SectionID'   => $PaymentType->alias,
        'SectionName' => $PaymentType->get('NameOrAlias', $hParams->{'LanguageID'}),
        'Attributes' => [
            {'ObjectID' => $PaymentType->id, 'AttributeAlias' => 'Logging'},
            {'ObjectID' => $RootObjectID,    'AttributeAlias' => 'PaynetKlarna_RegisterURL'},
            {'ObjectID' => $RootObjectID,    'AttributeAlias' => 'Paynet_AdminURL'},
            {'ObjectID' => $RootObjectID,    'AttributeAlias' => 'Paynet_PaymentURL'},
            {'ObjectID' => $RootObjectID,    'AttributeAlias' => 'Paynet_ShopSystemID'},
            {'ObjectID' => $RootObjectID,    'AttributeAlias' => 'Paynet_InterfaceVersion'}
        ]
    });

    return;
}

1;
